@@ -13,11 +13,10 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+import fnmatch
 import os
-import pkg_resources
 
 from oslo_log import log
-from oslo_utils import fnmatch
 import yaml
 
 LOG = log.getLogger(__name__)
@@ -30,7 +29,7 @@ class ConfigException(Exception):
         self.cfg = cfg
 
     def __str__(self):
-        return '%s %s: %s' % (self.cfg_type, self.cfg, self.msg)
+        return '{} {}: {}'.format(self.cfg_type, self.cfg, self.msg)
 
 
 class SourceException(Exception):
@@ -39,10 +38,10 @@ class SourceException(Exception):
         self.cfg = cfg
 
     def __str__(self):
-        return 'Source definition invalid: %s (%s)' % (self.msg, self.cfg)
+        return 'Source definition invalid: {} ({})'.format(self.msg, self.cfg)
 
 
-class ConfigManagerBase(object):
+class ConfigManagerBase:
     """Base class for managing configuration file refresh"""
 
     def __init__(self, conf):
@@ -57,15 +56,16 @@ class ConfigManagerBase(object):
             if not cfg_loc:
                 LOG.debug("No pipeline definitions configuration file found! "
                           "Using default config.")
-                cfg_loc = pkg_resources.resource_filename(
-                    __name__, 'pipeline/data/' + cfg_file)
+                cfg_loc = os.path.join(
+                    os.path.dirname(os.path.abspath(__file__)),
+                    'pipeline', 'data', cfg_file)
         with open(cfg_loc) as fap:
             conf = yaml.safe_load(fap)
         LOG.debug("Config file: %s", conf)
         return conf
 
 
-class Source(object):
+class Source:
     """Represents a generic source"""
 
     def __init__(self, cfg):
