@@ -11,12 +11,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from distutils import version
-
 from gnocchiclient import client
 from gnocchiclient import exceptions as gnocchi_exc
 import keystoneauth1.session
 from oslo_log import log
+from oslo_utils import versionutils
 
 from ceilometer import keystone_client
 
@@ -152,45 +151,6 @@ resources_update_operations = [
                                    "max_length": 255,
                                    "required": True}}
      }]},
-    {"desc": "add switch resource type",
-     "type": "create_resource_type",
-     "resource_type": "switch",
-     "data": [{
-         "attributes": {"controller": {"type": "string", "min_length": 0,
-                                       "max_length": 255, "required": True}}
-     }]},
-    {"desc": "add switch_port resource type",
-     "type": "create_resource_type",
-     "resource_type": "switch_port",
-     "data": [{
-         "attributes": {"switch": {"type": "string", "min_length": 0,
-                                   "max_length": 64, "required": True},
-                        "port_number_on_switch": {"type": "number", "min": 0,
-                                                  "max": 4294967295,
-                                                  "required": False},
-                        "neutron_port_id": {"type": "string",
-                                            "min_length": 0,
-                                            "max_length": 255,
-                                            "required": False},
-                        "controller": {"type": "string", "min_length": 0,
-                                       "max_length": 255, "required": True}}
-     }]},
-    {"desc": "add port resource type",
-     "type": "create_resource_type",
-     "resource_type": "port",
-     "data": [{
-         "attributes": {"controller": {"type": "string", "min_length": 0,
-                                       "max_length": 255, "required": True}}
-     }]},
-    {"desc": "add switch_table resource type",
-     "type": "create_resource_type",
-     "resource_type": "switch_table",
-     "data": [{
-         "attributes": {"switch": {"type": "string", "min_length": 0,
-                                   "max_length": 64, "required": True},
-                        "controller": {"type": "string", "min_length": 0,
-                                       "max_length": 255, "required": True}}
-     }]},
     {"desc": "add volume provider resource type",
      "type": "create_resource_type",
      "resource_type": "volume_provider",
@@ -240,18 +200,44 @@ resources_update_operations = [
          "value": {"type": "string", "min_length": 0, "max_length": 255,
                    "required": False}
      }]},
+    {"desc": "add volume_type_id to volume",
+     "type": "update_attribute_type",
+     "resource_type": "volume",
+     "data": [{
+         "op": "add",
+         "path": "/attributes/volume_type_id",
+         "value": {"type": "string", "min_length": 0, "max_length": 255,
+                   "required": False}
+     }]},
+    {"desc": "add storage_policy to swift_account",
+     "type": "update_attribute_type",
+     "resource_type": "swift_account",
+     "data": [{
+         "op": "add",
+         "path": "/attributes/storage_policy",
+         "value": {"type": "string", "min_length": 0, "max_length": 255,
+                   "required": False}  # Only containers have a storage policy
+     }]},
+    {"desc": "make host optional for instance",
+     "type": "update_attribute_type",
+     "resource_type": "instance",
+     "data": [{
+         "op": "add",  # Usually update, the attribute likely already exists
+         "path": "/attributes/host",
+         "value": {"type": "string", "min_length": 0, "max_length": 255,
+                   "required": False}  # Allow the hypervisor to be withheld
+     }]},
 ]
 
-# NOTE(sileht): We use LooseVersion because pbr can generate invalid
-# StrictVersion like 9.0.1.dev226
-REQUIRED_VERSION = version.LooseVersion("4.2.0")
+
+REQUIRED_VERSION = "4.2.0"
 
 
 def upgrade_resource_types(conf):
     gnocchi = get_gnocchiclient(conf)
 
-    gnocchi_version = version.LooseVersion(gnocchi.build.get())
-    if gnocchi_version < REQUIRED_VERSION:
+    gnocchi_version = gnocchi.build.get()
+    if not versionutils.is_compatible(REQUIRED_VERSION, gnocchi_version):
         raise Exception("required gnocchi version is %s, got %s" %
                         (REQUIRED_VERSION, gnocchi_version))
 
@@ -266,8 +252,15 @@ def upgrade_resource_types(conf):
         if ops['type'] == 'update_attribute_type':
             rt = gnocchi.resource_type.get(name=ops['resource_type'])
             first_op = ops['data'][0]
-            attrib = first_op['path'].replace('/attributes', '')
-            if first_op['op'] == 'add' and attrib in rt['attributes']:
+            attrib = first_op['path'].replace('/attributes/', '')
+            # Options are only used when adding/updating attributes.
+            # Make a shallow copy of the new value type, and remove options
+            # from the copy to make sure it isn't included in checks.
+            value = first_op['value'].copy()
+            value.pop('options', None)
+            if (first_op['op'] == 'add'
+                    and attrib in rt['attributes']
+                    and value == rt['attributes'][attrib]):
                 continue
             if first_op['op'] == 'remove' and attrib not in rt['attributes']:
                 continue
