@@ -14,7 +14,6 @@
 
 from oslo_log import log
 
-from ceilometer.i18n import _
 from ceilometer.ipmi.notifications import ironic as parser
 from ceilometer.ipmi.platform import exception as ipmiexcept
 from ceilometer.ipmi.platform import ipmi_sensor
@@ -32,7 +31,7 @@ class SensorPollster(plugin_base.PollsterBase):
     METRIC = None
 
     def setup_environment(self):
-        super(SensorPollster, self).setup_environment()
+        super().setup_environment()
         self.ipmi = ipmi_sensor.IPMISensor()
         self.polling_failures = 0
 
@@ -47,6 +46,11 @@ class SensorPollster(plugin_base.PollsterBase):
 
     @staticmethod
     def _get_sensor_types(data, sensor_type):
+        # Ipmitool reports 'Pwr Consumption' as sensor type 'Current'.
+        # Set sensor_type to 'Current' when polling 'Power' metrics.
+        if sensor_type == 'Power':
+            sensor_type = 'Current'
+
         try:
             return (sensor_type_data for _, sensor_type_data
                     in data[sensor_type].items())
@@ -59,12 +63,11 @@ class SensorPollster(plugin_base.PollsterBase):
             stats = self.ipmi.read_sensor_any(self.METRIC)
         except ipmiexcept.IPMIException:
             self.polling_failures += 1
-            LOG.warning(_(
-                'Polling %(mtr)s sensor failed for %(cnt)s times!')
-                % ({'mtr': self.METRIC,
-                    'cnt': self.polling_failures}))
+            LOG.warning(
+                'Polling %(mtr)s sensor failed for %(cnt)s times!',
+                {'mtr': self.METRIC, 'cnt': self.polling_failures})
             if 0 <= self.conf.ipmi.polling_retry < self.polling_failures:
-                LOG.warning(_('Pollster for %s is disabled!') % self.METRIC)
+                LOG.warning('Pollster for %s is disabled!', self.METRIC)
                 raise plugin_base.PollsterPermanentError(resources)
             else:
                 return
@@ -81,6 +84,10 @@ class SensorPollster(plugin_base.PollsterBase):
             except KeyError:
                 continue
 
+            # Do not pick up power consumption metrics from 'Current' sensor
+            if self.METRIC == 'Current' and 'Pwr Consumption' in sensor_id:
+                continue
+
             if not parser.validate_reading(sensor_reading):
                 continue
 
@@ -98,6 +105,10 @@ class SensorPollster(plugin_base.PollsterBase):
                 'node': self.conf.host
             }
 
+            extra_metadata = self.get_extra_sensor_metadata(sensor_data)
+            if extra_metadata:
+                metadata.update(extra_metadata)
+
             yield sample.Sample(
                 name='hardware.ipmi.%s' % self.METRIC.lower(),
                 type=sample.TYPE_GAUGE,
@@ -108,6 +119,11 @@ class SensorPollster(plugin_base.PollsterBase):
                 resource_id=resource_id,
                 resource_metadata=metadata)
 
+    def get_extra_sensor_metadata(self, sensor_data):
+        # override get_extra_sensor_metadata to add specific metrics for
+        # each sensor
+        return {}
+
 
 class TemperatureSensorPollster(SensorPollster):
     METRIC = 'Temperature'
@@ -120,6 +136,20 @@ class CurrentSensorPollster(SensorPollster):
 class FanSensorPollster(SensorPollster):
     METRIC = 'Fan'
 
+    def get_extra_sensor_metadata(self, sensor_data):
+        try:
+            return {
+                "maximum_rpm": sensor_data['Normal Maximum'],
+            }
+        except KeyError:
+            # Maximum rpm might not be reported when usage
+            # is reported as percent
+            return {}
+
 
 class VoltageSensorPollster(SensorPollster):
     METRIC = 'Voltage'
+
+
+class PowerSensorPollster(SensorPollster):
+    METRIC = 'Power'
