@@ -41,7 +41,7 @@ OPTS = [
 LOG = log.getLogger(__name__)
 
 
-class MeterDefinition(object):
+class MeterDefinition:
 
     SAMPLE_ATTRIBUTES = ["name", "type", "volume", "unit", "timestamp",
                          "user_id", "project_id", "resource_id"]
@@ -161,16 +161,15 @@ class MeterDefinition(object):
                     nb = (0 if nb_values == 1 and values[0] is None
                           else nb_values)
                     LOG.warning('Only %(nb)d fetched meters contain '
-                                '"%(name)s" field instead of %(total)d.' %
-                                dict(name=name, nb=nb,
-                                     total=nb_samples))
+                                '"%(name)s" field instead of %(total)d.',
+                                dict(name=name, nb=nb, total=nb_samples))
                     return
 
             # NOTE(sileht): Transform the sample with multiple values per
             # attribute into multiple samples with one value per attribute.
             for values in zip(*samples_values):
-                sample = dict((attributes[idx], value)
-                              for idx, value in enumerate(values))
+                sample = {attributes[idx]: value
+                          for idx, value in enumerate(values)}
 
                 if self._name_discovery and self._cache:
                     # populate user_name and project_name fields in the sample
@@ -193,7 +192,7 @@ class ProcessMeterNotifications(endpoint.SampleEndpoint):
     event_types = []
 
     def __init__(self, conf, publisher):
-        super(ProcessMeterNotifications, self).__init__(conf, publisher)
+        super().__init__(conf, publisher)
         self.definitions = self._load_definitions()
 
     def _load_definitions(self):
@@ -212,14 +211,13 @@ class ProcessMeterNotifications(endpoint.SampleEndpoint):
             for meter_cfg in reversed(meters_cfg['metric']):
                 if meter_cfg.get('name') in definitions:
                     # skip duplicate meters
-                    LOG.warning("Skipping duplicate meter definition %s"
-                                % meter_cfg)
+                    LOG.warning("Skipping duplicate meter definition %s",
+                                meter_cfg)
                     continue
                 try:
                     md = MeterDefinition(meter_cfg, self.conf, plugin_manager)
                 except declarative.DefinitionException as e:
-                    errmsg = "Error loading meter definition: %s"
-                    LOG.error(errmsg, str(e))
+                    LOG.error("Error loading meter definition: %s", e)
                 else:
                     definitions[meter_cfg['name']] = md
         return definitions.values()
