@@ -17,7 +17,6 @@ import warnings
 
 from oslo_log import log
 
-from ceilometer.i18n import _
 from ceilometer.network.services import base
 from ceilometer import sample
 
@@ -35,7 +34,7 @@ class FirewallPollster(base.BaseServicesPollster):
               ]
 
     def __init__(self, conf):
-        super(FirewallPollster, self).__init__(conf)
+        super().__init__(conf)
 
         warnings.warn('Support for Neutron FWaaS has been deprecated '
                       'and will be removed in a future release.',
@@ -49,13 +48,13 @@ class FirewallPollster(base.BaseServicesPollster):
         resources = resources or []
 
         for fw in resources:
-            LOG.debug("Firewall : %s" % fw)
+            LOG.debug("Firewall : %s", fw)
             status = self.get_status_id(fw['status'])
             if status == -1:
                 # unknown status, skip this sample
-                LOG.warning(_("Unknown status %(stat)s received on fw %(id)s,"
-                            "skipping sample") % {'stat': fw['status'],
-                                                  'id': fw['id']})
+                LOG.warning("Unknown status %(stat)s received on fw %(id)s,"
+                            "skipping sample",
+                            {'stat': fw['status'], 'id': fw['id']})
                 continue
 
             yield sample.Sample(
@@ -82,7 +81,7 @@ class FirewallPolicyPollster(base.BaseServicesPollster):
               ]
 
     def __init__(self, conf):
-        super(FirewallPolicyPollster, self).__init__(conf)
+        super().__init__(conf)
 
         warnings.warn('Support for Neutron FWaaS has been deprecated '
                       'and will be removed in a future release.',
@@ -96,7 +95,7 @@ class FirewallPolicyPollster(base.BaseServicesPollster):
         resources = resources or []
 
         for fw in resources:
-            LOG.debug("Firewall Policy: %s" % fw)
+            LOG.debug("Firewall Policy: %s", fw)
 
             yield sample.Sample(
                 name='network.services.firewall.policy',
