@@ -22,15 +22,6 @@ from oslo_log import log
 
 from ceilometer import keystone_client
 
-OPTS = [
-    cfg.BoolOpt('nova_http_log_debug',
-                default=False,
-                # Added in Mitaka
-                deprecated_for_removal=True,
-                help=('Allow novaclient\'s debug log output. '
-                      '(Use default_log_levels instead)')),
-]
-
 SERVICE_OPTS = [
     cfg.StrOpt('nova',
                default='compute',
@@ -53,17 +44,13 @@ def logged(func):
     return with_logging
 
 
-class Client(object):
+class Client:
     """A client which gets information via python-novaclient."""
 
     def __init__(self, conf):
         """Initialize a nova client object."""
         creds = conf.service_credentials
 
-        logger = None
-        if conf.nova_http_log_debug:
-            logger = log.getLogger("novaclient-debug")
-            logger.logger.setLevel(log.DEBUG)
         ks_session = keystone_client.get_session(conf)
 
         self.nova_client = nova_client.Client(
@@ -73,8 +60,7 @@ class Client(object):
             # nova adapter options
             region_name=creds.region_name,
             endpoint_type=creds.interface,
-            service_type=conf.service_types.nova,
-            logger=logger)
+            service_type=conf.service_types.nova)
 
         self.glance_client = glanceclient.Client(
             version='2',
@@ -142,6 +128,17 @@ class Client(object):
             ameta = image_metadata.get(attr) if image_metadata else default
             setattr(instance, attr, ameta)
 
+        if image:
+            image_meta = {"base_image_ref": iid}
+            # Notifications and libvirt XML metadata return all
+            # image_meta values as strings. Do the same here.
+            image_meta.update((k, str(v))
+                              for k, v in image.items()
+                              if k not in ('id', 'name', 'metadata'))
+        else:
+            image_meta = {}
+        instance.image_meta = image_meta
+
     @logged
     def instance_get_all_by_host(self, hostname, since=None):
         """Returns list of instances on particular host.
@@ -155,17 +152,3 @@ class Client(object):
         return self._with_flavor_and_image(self.nova_client.servers.list(
             detailed=True,
             search_opts=search_opts))
-
-    @logged
-    def instance_get_all(self, since=None):
-        """Returns list of all instances.
-
-        If since is supplied, it will return the instances changes since that
-        datetime. since should be in ISO Format '%Y-%m-%dT%H:%M:%SZ'
-        """
-        search_opts = {'all_tenants': True}
-        if since:
-            search_opts['changes-since'] = since
-        return self.nova_client.servers.list(
-            detailed=True,
-            search_opts=search_opts)
