@@ -17,13 +17,13 @@ import socket
 from keystoneauth1 import loading
 from oslo_config import cfg
 
+import ceilometer.alarm.discovery
+import ceilometer.cmd.polling
 import ceilometer.compute.discovery
 import ceilometer.compute.virt.inspector
 import ceilometer.compute.virt.libvirt.utils
-import ceilometer.compute.virt.vmware.inspector
 import ceilometer.event.converter
 import ceilometer.image.discovery
-import ceilometer.ipmi.platform.intel_node_manager
 import ceilometer.ipmi.pollsters
 import ceilometer.keystone_client
 import ceilometer.meter.notifications
@@ -45,12 +45,12 @@ OPTS = [
     cfg.HostAddressOpt('host',
                        default=socket.gethostname(),
                        sample_default='<your_hostname>',
-                       help='Name of this node, which must be valid in an '
-                       'AMQP key. Can be an opaque identifier. For ZeroMQ '
-                       'only, must be a valid host name, FQDN, or IP '
-                       'address.'),
+                       help='Hostname, FQDN or IP address of this host. '
+                            'Must be valid within AMQP key.'),
     cfg.IntOpt('http_timeout',
                default=600,
+               deprecated_for_removal=True,
+               deprecated_reason='This option has no effect',
                help='Timeout seconds for HTTP requests. Set it to None to '
                     'disable timeout.'),
     cfg.IntOpt('max_parallel_requests',
@@ -66,7 +66,8 @@ def list_opts():
     # This have been removed due to a recursive import issue
     return [
         ('DEFAULT',
-         itertools.chain(ceilometer.compute.virt.inspector.OPTS,
+         itertools.chain(ceilometer.cmd.polling.CLI_OPTS,
+                         ceilometer.compute.virt.inspector.OPTS,
                          ceilometer.compute.virt.libvirt.utils.OPTS,
                          ceilometer.objectstore.swift.OPTS,
                          ceilometer.pipeline.base.OPTS,
@@ -86,9 +87,7 @@ def list_opts():
                 'single instance of that service is running.')
         ]),
         ('event', ceilometer.event.converter.OPTS),
-        ('ipmi',
-         itertools.chain(ceilometer.ipmi.platform.intel_node_manager.OPTS,
-                         ceilometer.ipmi.pollsters.OPTS)),
+        ('ipmi', ceilometer.ipmi.pollsters.OPTS),
         ('meter', ceilometer.meter.notifications.OPTS),
         ('notification',
          itertools.chain(ceilometer.notification.OPTS,
@@ -99,13 +98,13 @@ def list_opts():
         ('rgw_admin_credentials', ceilometer.objectstore.rgw.CREDENTIAL_OPTS),
         ('rgw_client', ceilometer.objectstore.rgw.CLIENT_OPTS),
         ('service_types',
-         itertools.chain(ceilometer.image.discovery.SERVICE_OPTS,
+         itertools.chain(ceilometer.alarm.discovery.SERVICE_OPTS,
+                         ceilometer.image.discovery.SERVICE_OPTS,
                          ceilometer.neutron_client.SERVICE_OPTS,
                          ceilometer.nova_client.SERVICE_OPTS,
                          ceilometer.objectstore.rgw.SERVICE_OPTS,
                          ceilometer.objectstore.swift.SERVICE_OPTS,
-                         ceilometer.volume.discovery.SERVICE_OPTS,)),
-        ('vmware', ceilometer.compute.virt.vmware.inspector.OPTS),
+                         ceilometer.volume.discovery.SERVICE_OPTS,))
     ]
 
 
