@@ -106,6 +106,32 @@ POLLING_OPTS = [
                 default=False,
                 help='Whether the polling service should ignore '
                      'disabled projects or not.'),
+    cfg.BoolOpt('prometheus_tls_enable',
+                default=False,
+                help='Whether it will expose tls metrics or not'),
+    cfg.StrOpt('prometheus_tls_certfile',
+               default=None,
+               help='The certificate file to allow this ceilometer to '
+                    'expose tls scrape endpoints'),
+    cfg.StrOpt('prometheus_tls_keyfile',
+               default=None,
+               help='The private key to allow this ceilometer to '
+                    'expose tls scrape endpoints'),
+    cfg.IntOpt('threads_to_process_pollsters',
+               default=1,
+               min=0,
+               help='The number of threads used to process the pollsters.'
+                    'The value one (1) means that the processing is in a'
+                    'serial fashion (not ordered!). The value zero (0) means '
+                    'that the we will use as much threads as the number of '
+                    'pollsters configured in the polling task. Any other'
+                    'positive integer can be used to fix an upper bound limit'
+                    'to the number of threads used for processing pollsters in'
+                    'parallel. One must bear in mind that, using more than one'
+                    'thread might not take full advantage of the discovery '
+                    'cache and pollsters cache processes; it is possible '
+                    'though to improve/use pollsters that synchronize '
+                    'themselves in the cache objects.'),
 ]
 
 
@@ -115,15 +141,15 @@ def hash_of_set(s):
 
 class PollingException(agent.ConfigException):
     def __init__(self, message, cfg):
-        super(PollingException, self).__init__('Polling', message, cfg)
+        super().__init__('Polling', message, cfg)
 
 
 class HeartBeatException(agent.ConfigException):
     def __init__(self, message, cfg):
-        super(HeartBeatException, self).__init__('Polling', message, cfg)
+        super().__init__('Polling', message, cfg)
 
 
-class Resources(object):
+class Resources:
     def __init__(self, agent_manager):
         self.agent_manager = agent_manager
         self._resources = []
@@ -152,7 +178,7 @@ class Resources(object):
 
     @staticmethod
     def key(source_name, pollster):
-        return '%s-%s' % (source_name, pollster.name)
+        return '{}-{}'.format(source_name, pollster.name)
 
 
 def iter_random(iterable):
@@ -162,7 +188,7 @@ def iter_random(iterable):
     return iter(lst)
 
 
-class PollingTask(object):
+class PollingTask:
     """Polling task for polling samples and notifying.
 
     A polling task can be invoked periodically or only once.
@@ -187,7 +213,12 @@ class PollingTask(object):
         self._name_discovery = conf.polling.identity_name_discovery
         self._cache = cache_utils.get_client(conf)
 
+        # element that provides a map between source names and source object
+        self.sources_map = dict()
+
     def add(self, pollster, source):
+        self.sources_map[source.name] = source
+
         self.pollster_matches[source.name].add(pollster)
         key = Resources.key(source.name, pollster)
         self.resources[key].setup(source)
@@ -199,119 +230,211 @@ class PollingTask(object):
         poll_history = {}
         for source_name, pollsters in iter_random(
                 self.pollster_matches.items()):
-            for pollster in iter_random(pollsters):
-                key = Resources.key(source_name, pollster)
-                candidate_res = list(
-                    self.resources[key].get(discovery_cache))
-                if not candidate_res and pollster.obj.default_discovery:
-                    candidate_res = self.manager.discover(
-                        [pollster.obj.default_discovery], discovery_cache)
+            self.execute_polling_task_processing(cache, discovery_cache,
+                                                 poll_history, pollsters,
+                                                 source_name)
 
-                # Remove duplicated resources and black resources. Using
-                # set() requires well defined __hash__ for each resource.
-                # Since __eq__ is defined, 'not in' is safe here.
-                polling_resources = []
-                black_res = self.resources[key].blacklist
-                history = poll_history.get(pollster.name, [])
-                for x in candidate_res:
-                    if x not in history:
-                        history.append(x)
-                        if x not in black_res:
-                            polling_resources.append(x)
-                poll_history[pollster.name] = history
+    def execute_polling_task_processing(self, cache, discovery_cache,
+                                        poll_history, pollsters, source_name):
+        all_pollsters = list(pollsters)
+        number_workers_for_pollsters =\
+            self.manager.conf.polling.threads_to_process_pollsters
 
-                # If no resources, skip for this pollster
-                if not polling_resources:
-                    p_context = 'new ' if history else ''
-                    LOG.debug("Skip pollster %(name)s, no %(p_context)s "
-                              "resources found this cycle",
-                              {'name': pollster.name, 'p_context': p_context})
-                    continue
+        if number_workers_for_pollsters < 0:
+            raise RuntimeError("The configuration "
+                               "'threads_to_process_pollsters' has a negative "
+                               "value [%s], which should not be allowed.",
+                               number_workers_for_pollsters)
 
-                LOG.info("Polling pollster %(poll)s in the context of "
-                         "%(src)s",
-                         dict(poll=pollster.name, src=source_name))
-                try:
-                    polling_timestamp = timeutils.utcnow().isoformat()
-                    samples = pollster.obj.get_samples(
-                        manager=self.manager,
-                        cache=cache,
-                        resources=polling_resources
-                    )
-                    sample_batch = []
+        if number_workers_for_pollsters == 0:
+            number_workers_for_pollsters = len(all_pollsters)
 
-                    self.manager.heartbeat(pollster.name, polling_timestamp)
+        if number_workers_for_pollsters < len(all_pollsters):
+            LOG.debug("The number of pollsters in source [%s] is bigger "
+                      "than the number of worker threads to execute them. "
+                      "Therefore, one can expect the process to be longer "
+                      "than the expected.", source_name)
 
-                    for sample in samples:
-                        # Note(yuywz): Unify the timestamp of polled samples
-                        sample.set_timestamp(polling_timestamp)
+        all_pollster_scheduled = []
+        with futures.ThreadPoolExecutor(
+                thread_name_prefix="Pollster-executor",
+                max_workers=number_workers_for_pollsters) as executor:
+            LOG.debug("Processing pollsters for [%s] with [%s] threads.",
+                      source_name, number_workers_for_pollsters)
 
-                        if self._name_discovery and self._cache:
+            for pollster in all_pollsters:
+                all_pollster_scheduled.append(
+                    self.register_pollster_execution(
+                        cache, discovery_cache, executor, poll_history,
+                        pollster, source_name))
 
-                            # Try to resolve project UUIDs from cache first,
-                            # and then keystone
-                            LOG.debug("Ceilometer is configured to resolve "
-                                      "project IDs to name; loading the "
-                                      "project name for project ID [%s] in "
-                                      "sample [%s].", sample.project_id,
-                                      sample)
-                            if sample.project_id:
-                                sample.project_name = \
-                                    self._cache.resolve_uuid_from_cache(
-                                        "projects",
-                                        sample.project_id
-                                    )
+        for s in all_pollster_scheduled:
+            LOG.debug(s.result())
 
-                            # Try to resolve user UUIDs from cache first,
-                            # and then keystone
+    def register_pollster_execution(self, cache, discovery_cache, executor,
+                                    poll_history, pollster, source_name):
+        LOG.debug("Registering pollster [%s] from source [%s] to be executed "
+                  "via executor [%s] with cache [%s], pollster history [%s], "
+                  "and discovery cache [%s].", pollster, source_name, executor,
+                  cache, poll_history, discovery_cache)
 
-                            LOG.debug("Ceilometer is configured to resolve "
-                                      "user IDs to name; loading the "
-                                      "user name for user ID [%s] in "
-                                      "sample [%s].", sample.user_id,
-                                      sample)
-                            if sample.user_id:
-                                sample.user_name = \
-                                    self._cache.resolve_uuid_from_cache(
-                                        "users",
-                                        sample.user_id
-                                    )
+        def _internal_function():
+            self._internal_pollster_run(cache, discovery_cache, poll_history,
+                                        pollster, source_name)
+            return "Finished processing pollster [%s]." % pollster.name
 
-                            LOG.debug("Final sample generated after loading "
-                                      "the project and user names bases on "
-                                      "the IDs [%s].", sample)
+        return executor.submit(_internal_function)
 
-                        sample_dict = (
-                            publisher_utils.meter_message_from_counter(
-                                sample, self._telemetry_secret
-                            ))
-                        if self._batch_size:
-                            if len(sample_batch) >= self._batch_size:
-                                self._send_notification(sample_batch)
-                                sample_batch = []
-                            sample_batch.append(sample_dict)
-                        else:
-                            self._send_notification([sample_dict])
+    def _internal_pollster_run(self, cache, discovery_cache, poll_history,
+                               pollster, source_name):
+        key = Resources.key(source_name, pollster)
+        candidate_res = list(
+            self.resources[key].get(discovery_cache))
+        if not candidate_res and pollster.obj.default_discovery:
+            LOG.debug("Executing discovery process for pollsters [%s] "
+                      "and discovery method [%s] via process [%s].",
+                      pollster.obj, pollster.obj.default_discovery,
+                      self.manager.discover)
 
-                    if sample_batch:
+            candidate_res = self.manager.discover(
+                [pollster.obj.default_discovery], discovery_cache)
+
+        # Remove duplicated resources and black resources. Using
+        # set() requires well defined __hash__ for each resource.
+        # Since __eq__ is defined, 'not in' is safe here.
+        polling_resources = []
+        black_res = self.resources[key].blacklist
+        history = poll_history.get(pollster.name, [])
+        for x in candidate_res:
+            if x not in history:
+                history.append(x)
+                if x not in black_res:
+                    polling_resources.append(x)
+        poll_history[pollster.name] = history
+
+        # If no resources, skip for this pollster
+        if not polling_resources:
+            p_context = 'new' if history else ''
+            LOG.debug("Skip pollster %(name)s, no %(p_context)s "
+                      "resources found this cycle",
+                      {'name': pollster.name, 'p_context': p_context})
+            return
+
+        LOG.info("Polling pollster %(poll)s in the context of "
+                 "%(src)s",
+                 dict(poll=pollster.name, src=source_name))
+        try:
+            source_obj = self.sources_map[source_name]
+            coordination_group_name = source_obj.group_for_coordination
+
+            LOG.debug("Checking if we need coordination for pollster "
+                      "[%s] with coordination group name [%s].",
+                      pollster, coordination_group_name)
+            if self.manager.hashrings and self.manager.hashrings.get(
+                    coordination_group_name):
+                LOG.debug("The pollster [%s] is configured in a "
+                          "source for polling that requires "
+                          "coordination under name [%s].", pollster,
+                          coordination_group_name)
+                group_coordination = self.manager.hashrings[
+                    coordination_group_name].belongs_to_self(
+                    str(pollster.name))
+
+                LOG.debug("Pollster [%s] is configured with "
+                          "coordination [%s] under name [%s].",
+                          pollster.name, group_coordination,
+                          coordination_group_name)
+                if not group_coordination:
+                    LOG.info("The pollster [%s] should be processed "
+                             "by other node.", pollster.name)
+                    return
+            else:
+                LOG.debug("The pollster [%s] is not configured in a "
+                          "source for polling that requires "
+                          "coordination. The current hashrings are "
+                          "the following [%s].", pollster,
+                          self.manager.hashrings)
+
+            polling_timestamp = timeutils.utcnow().isoformat()
+            samples = pollster.obj.get_samples(
+                manager=self.manager,
+                cache=cache,
+                resources=polling_resources
+            )
+            sample_batch = []
+
+            self.manager.heartbeat(pollster.name, polling_timestamp)
+
+            for sample in samples:
+                # Note(yuywz): Unify the timestamp of polled samples
+                sample.set_timestamp(polling_timestamp)
+
+                if self._name_discovery and self._cache:
+
+                    # Try to resolve project UUIDs from cache first,
+                    # and then keystone
+                    LOG.debug("Ceilometer is configured to resolve "
+                              "project IDs to name; loading the "
+                              "project name for project ID [%s] in "
+                              "sample [%s].", sample.project_id,
+                              sample)
+                    if sample.project_id:
+                        sample.project_name = \
+                            self._cache.resolve_uuid_from_cache(
+                                "projects",
+                                sample.project_id
+                            )
+
+                    # Try to resolve user UUIDs from cache first,
+                    # and then keystone
+                    LOG.debug("Ceilometer is configured to resolve "
+                              "user IDs to name; loading the "
+                              "user name for user ID [%s] in "
+                              "sample [%s].", sample.user_id,
+                              sample)
+
+                    if sample.user_id:
+                        sample.user_name = \
+                            self._cache.resolve_uuid_from_cache(
+                                "users",
+                                sample.user_id
+                            )
+
+                    LOG.debug("Final sample generated after loading "
+                              "the project and user names bases on "
+                              "the IDs [%s].", sample)
+
+                sample_dict = (
+                    publisher_utils.meter_message_from_counter(
+                        sample, self._telemetry_secret
+                    ))
+                if self._batch_size:
+                    if len(sample_batch) >= self._batch_size:
                         self._send_notification(sample_batch)
+                        sample_batch = []
+                    sample_batch.append(sample_dict)
+                else:
+                    self._send_notification([sample_dict])
 
-                    LOG.info("Finished polling pollster %(poll)s in the "
-                             "context of %(src)s", dict(poll=pollster.name,
-                                                        src=source_name))
-                except plugin_base.PollsterPermanentError as err:
-                    LOG.error(
-                        'Prevent pollster %(name)s from '
-                        'polling %(res_list)s on source %(source)s anymore!',
-                        dict(name=pollster.name,
-                             res_list=str(err.fail_res_list),
-                             source=source_name))
-                    self.resources[key].blacklist.extend(err.fail_res_list)
-                except Exception as err:
-                    LOG.error(
-                        'Continue after error from %(name)s: %(error)s'
-                        % ({'name': pollster.name, 'error': err}),
-                        exc_info=True)
+            if sample_batch:
+                self._send_notification(sample_batch)
+
+            LOG.info("Finished polling pollster %(poll)s in the "
+                     "context of %(src)s", dict(poll=pollster.name,
+                                                src=source_name))
+        except plugin_base.PollsterPermanentError as err:
+            LOG.error(
+                'Prevent pollster %(name)s from '
+                'polling %(res_list)s on source %(source)s anymore!',
+                dict(name=pollster.name,
+                     res_list=str(err.fail_res_list),
+                     source=source_name))
+            self.resources[key].blacklist.extend(err.fail_res_list)
+        except Exception as err:
+            LOG.error(
+                'Continue after error from %(name)s: %(error)s',
+                {'name': pollster.name, 'error': err},
+                exc_info=True)
 
     def _send_notification(self, samples):
         if self.manager.conf.polling.enable_notifications:
@@ -326,7 +449,7 @@ class PollingTask(object):
 
 class AgentHeartBeatManager(cotyledon.Service):
     def __init__(self, worker_id, conf, namespaces=None, queue=None):
-        super(AgentHeartBeatManager, self).__init__(worker_id)
+        super().__init__(worker_id)
         self.conf = conf
 
         if conf.polling.heartbeat_socket_dir is None:
@@ -351,7 +474,7 @@ class AgentHeartBeatManager(cotyledon.Service):
         try:
             self._sock.bind(self._sock_pth)
             self._sock.listen(1)
-        except socket.error as err:
+        except OSError as err:
             raise HeartBeatException("Failed to open socket file "
                                      f"({self._sock_pth}): {err}", conf)
 
@@ -388,7 +511,7 @@ class AgentHeartBeatManager(cotyledon.Service):
         LOG.debug(f"Reported heartbeat status:\n{out}")
 
     def run(self):
-        super(AgentHeartBeatManager, self).run()
+        super().run()
 
         LOG.debug("Started heartbeat child process.")
 
@@ -414,7 +537,7 @@ class AgentManager(cotyledon.Service):
         namespaces = namespaces or ['compute', 'central']
         group_prefix = conf.polling.partitioning_group_prefix
 
-        super(AgentManager, self).__init__(worker_id)
+        super().__init__(worker_id)
 
         self.conf = conf
         self._queue = queue
@@ -426,17 +549,24 @@ class AgentManager(cotyledon.Service):
         # be passed
         extensions = (self._extensions('poll', namespace, self.conf).extensions
                       for namespace in namespaces)
+        extensions = list(itertools.chain(*list(extensions)))
+
         # get the extensions from pollster builder
         extensions_fb = (self._extensions_from_builder('poll', namespace)
                          for namespace in namespaces)
+        extensions_fb = list(itertools.chain(*list(extensions_fb)))
+
+        # NOTE(tkajinam): Remove this after 2026.1 release
+        if extensions_fb:
+            LOG.warning('Support for pollster build has been deprecated')
 
         # Create dynamic pollsters
         extensions_dynamic_pollsters = self.create_dynamic_pollsters(
             namespaces)
+        extensions_dynamic_pollsters = list(extensions_dynamic_pollsters)
 
-        self.extensions = list(itertools.chain(*list(extensions))) + list(
-            itertools.chain(*list(extensions_fb))) + list(
-            extensions_dynamic_pollsters)
+        self.extensions = (
+            extensions + extensions_fb + extensions_dynamic_pollsters)
 
         if not self.extensions:
             LOG.warning('No valid pollsters can be loaded from %s '
@@ -459,7 +589,7 @@ class AgentManager(cotyledon.Service):
         # Compose coordination group prefix.
         # We'll use namespaces as the basement for this partitioning.
         namespace_prefix = '-'.join(sorted(namespaces))
-        self.group_prefix = ('%s-%s' % (namespace_prefix, group_prefix)
+        self.group_prefix = ('{}-{}'.format(namespace_prefix, group_prefix)
                              if group_prefix else namespace_prefix)
 
         if self.conf.polling.enable_notifications:
@@ -473,7 +603,20 @@ class AgentManager(cotyledon.Service):
                 address = netutils.parse_host_port(addr)
                 if address[0] is None or address[1] is None:
                     LOG.warning('Ignoring invalid address: %s', addr)
-                prom_exporter.export(address[0], address[1])
+                certfile = self.conf.polling.prometheus_tls_certfile
+                keyfile = self.conf.polling.prometheus_tls_keyfile
+                if self.conf.polling.prometheus_tls_enable:
+                    if not certfile or not keyfile:
+                        raise ValueError(
+                            "Certfile and keyfile must be provided."
+                        )
+                else:
+                    certfile = keyfile = None
+                prom_exporter.export(
+                    address[0],
+                    address[1],
+                    certfile,
+                    keyfile)
 
         self._keystone = None
         self._keystone_last_exception = None
@@ -601,12 +744,12 @@ class AgentManager(cotyledon.Service):
         )
 
     def _extensions(self, category, agent_ns=None, *args, **kwargs):
-        namespace = ('ceilometer.%s.%s' % (category, agent_ns) if agent_ns
+        namespace = ('ceilometer.{}.{}'.format(category, agent_ns) if agent_ns
                      else 'ceilometer.%s' % category)
         return self._get_ext_mgr(namespace, *args, **kwargs)
 
     def _extensions_from_builder(self, category, agent_ns=None):
-        ns = ('ceilometer.builder.%s.%s' % (category, agent_ns) if agent_ns
+        ns = ('ceilometer.builder.{}.{}'.format(category, agent_ns) if agent_ns
               else 'ceilometer.builder.%s' % category)
         mgr = self._get_ext_mgr(ns, self.conf)
 
@@ -621,19 +764,68 @@ class AgentManager(cotyledon.Service):
             return []
 
     def join_partitioning_groups(self):
-        groups = set([self.construct_group_id(d.obj.group_id)
-                      for d in self.discoveries])
+        groups = set()
+        for d in self.discoveries:
+            generated_group_id = self.construct_group_id(d.obj.group_id)
+            LOG.debug("Adding discovery [%s] with group ID [%s] to build the "
+                      "coordination partitioning via constructed group ID "
+                      "[%s].", d.__dict__, d.obj.group_id, generated_group_id)
+            groups.add(generated_group_id)
+
         # let each set of statically-defined resources have its own group
-        static_resource_groups = set([
-            self.construct_group_id(hash_of_set(p.resources))
-            for p in self.polling_manager.sources
-            if p.resources
-        ])
+        static_resource_groups = set()
+        for p in self.polling_manager.sources:
+            if p.resources:
+                generated_group_id = self.construct_group_id(
+                    hash_of_set(p.resources))
+                LOG.debug("Adding pollster group [%s] with resources [%s] to "
+                          "build the coordination partitioning via "
+                          "constructed group ID [%s].", p, p.resources,
+                          generated_group_id)
+                static_resource_groups.add(generated_group_id)
+            else:
+                LOG.debug("Pollster group [%s] does not have resources defined"
+                          "to build the group ID for coordination.", p)
+
         groups.update(static_resource_groups)
 
-        self.hashrings = dict(
-            (group, self.partition_coordinator.join_partitioned_group(group))
-            for group in groups)
+        # (rafaelweingartner) here we will configure the dynamic
+        # coordination process. It is useful to sync pollster that do not rely
+        # on discovery process, such as the dynamic pollster on compute nodes.
+        dynamic_pollster_groups_for_coordination = set()
+        for p in self.polling_manager.sources:
+            if p.group_id_coordination_expression:
+                if p.resources:
+                    LOG.warning("The pollster group [%s] has resources to "
+                                "execute coordination. Therefore, we do not "
+                                "add it via the dynamic coordination process.",
+                                p.name)
+                    continue
+                group_prefix = p.name
+                generated_group_id = eval(p.group_id_coordination_expression)
+
+                group_for_coordination = "{}-{}".format(
+                    group_prefix, generated_group_id)
+                dynamic_pollster_groups_for_coordination.add(
+                    group_for_coordination)
+
+                p.group_for_coordination = group_for_coordination
+                LOG.debug("Adding pollster group [%s] with dynamic "
+                          "coordination to build the coordination "
+                          "partitioning via constructed group ID [%s].",
+                          p, dynamic_pollster_groups_for_coordination)
+            else:
+                LOG.debug("Pollster group [%s] does not have an expression to "
+                          "dynamically use in the coordination process.", p)
+
+        groups.update(dynamic_pollster_groups_for_coordination)
+
+        self.hashrings = {
+            group: self.partition_coordinator.join_partitioned_group(group)
+            for group in groups}
+
+        LOG.debug("Hashrings [%s] created for pollsters definition.",
+                  self.hashrings)
 
     def setup_polling_tasks(self):
         polling_tasks = {}
@@ -648,7 +840,7 @@ class AgentManager(cotyledon.Service):
         return polling_tasks
 
     def construct_group_id(self, discovery_group_id):
-        return '%s-%s' % (self.group_prefix, discovery_group_id)
+        return '{}-{}'.format(self.group_prefix, discovery_group_id)
 
     def start_polling_tasks(self):
         data = self.setup_polling_tasks()
@@ -672,7 +864,7 @@ class AgentManager(cotyledon.Service):
         utils.spawn_thread(self.polling_periodics.start, allow_empty=True)
 
     def run(self):
-        super(AgentManager, self).run()
+        super().run()
         self.polling_manager = PollingManager(self.conf)
         if self.partition_coordinator:
             self.partition_coordinator.start(start_heart=True)
@@ -683,7 +875,7 @@ class AgentManager(cotyledon.Service):
         self.stop_pollsters_tasks()
         if self.partition_coordinator:
             self.partition_coordinator.stop()
-        super(AgentManager, self).terminate()
+        super().terminate()
 
     def interval_task(self, task):
         # NOTE(sileht): remove the previous keystone client
@@ -824,7 +1016,7 @@ class PollingManager(agent.ConfigManagerBase):
         specific pollster to decide how to use it.
 
         """
-        super(PollingManager, self).__init__(conf)
+        super().__init__(conf)
         cfg = self.load_config(conf.polling.cfg_file)
         self.sources = []
         if 'sources' not in cfg:
@@ -844,7 +1036,7 @@ class PollingSource(agent.Source):
 
     def __init__(self, cfg):
         try:
-            super(PollingSource, self).__init__(cfg)
+            super().__init__(cfg)
         except agent.SourceException as err:
             raise PollingException(err.msg, cfg)
         try:
@@ -872,6 +1064,12 @@ class PollingSource(agent.Source):
         except agent.SourceException as err:
             raise PollingException(err.msg, cfg)
 
+        self.group_id_coordination_expression = cfg.get(
+            'group_id_coordination_expression')
+
+        # This value is configured when coordination is enabled.
+        self.group_for_coordination = None
+
     def get_interval(self):
         return self.interval
 
