@@ -23,11 +23,9 @@ import threading
 from oslo_config import cfg
 from oslo_log import log
 import oslo_messaging
-from oslo_utils import encodeutils
 from oslo_utils import excutils
 from urllib import parse as urlparse
 
-from ceilometer.i18n import _
 from ceilometer import messaging
 from ceilometer import publisher
 from ceilometer.publisher import utils
@@ -59,20 +57,18 @@ NOTIFIER_OPTS = [
 
 class DeliveryFailure(Exception):
     def __init__(self, message=None, cause=None):
-        super(DeliveryFailure, self).__init__(message)
+        super().__init__(message)
         self.cause = cause
 
 
 def raise_delivery_failure(exc):
-    excutils.raise_with_cause(DeliveryFailure,
-                              encodeutils.exception_to_unicode(exc),
-                              cause=exc)
+    excutils.raise_with_cause(DeliveryFailure, str(exc), cause=exc)
 
 
 class MessagingPublisher(publisher.ConfigPublisherBase, metaclass=abc.ABCMeta):
 
     def __init__(self, conf, parsed_url):
-        super(MessagingPublisher, self).__init__(conf, parsed_url)
+        super().__init__(conf, parsed_url)
         options = urlparse.parse_qs(parsed_url.query)
         # the value of options is a list of url param values
         # only take care of the latest one if the option
@@ -91,8 +87,8 @@ class MessagingPublisher(publisher.ConfigPublisherBase, metaclass=abc.ABCMeta):
         if self.policy in ['default', 'queue', 'drop']:
             LOG.info('Publishing policy set to %s', self.policy)
         else:
-            LOG.warning(_('Publishing policy is unknown (%s) force to '
-                          'default'), self.policy)
+            LOG.warning('Publishing policy is unknown (%s) force to default',
+                        self.policy)
             self.policy = 'default'
 
         self.retry = 1 if self.policy in ['queue', 'drop'] else None
@@ -145,8 +141,8 @@ class MessagingPublisher(publisher.ConfigPublisherBase, metaclass=abc.ABCMeta):
         if queue_length > self.max_queue_length > 0:
             count = queue_length - self.max_queue_length
             self.local_queue = self.local_queue[count:]
-            LOG.warning(_("Publisher max local_queue length is exceeded, "
-                        "dropping %d oldest samples") % count)
+            LOG.warning("Publisher max local_queue length is exceeded, "
+                        "dropping %d oldest samples", count)
 
     def _process_queue(self, queue, policy):
         current_retry = 0
@@ -157,12 +153,12 @@ class MessagingPublisher(publisher.ConfigPublisherBase, metaclass=abc.ABCMeta):
             except DeliveryFailure:
                 data = sum([len(m) for __, m in queue])
                 if policy == 'queue':
-                    LOG.warning(_("Failed to publish %d datapoints, queue "
-                                  "them"), data)
+                    LOG.warning("Failed to publish %d datapoints, queue them",
+                                data)
                     return queue
                 elif policy == 'drop':
-                    LOG.warning(_("Failed to publish %d datapoints, "
-                                "dropping them"), data)
+                    LOG.warning("Failed to publish %d datapoints, "
+                                "dropping them", data)
                     return []
                 current_retry += 1
                 if current_retry >= self.max_retry:
@@ -228,7 +224,7 @@ class NotifierPublisher(MessagingPublisher):
     """
 
     def __init__(self, conf, parsed_url, default_topic):
-        super(NotifierPublisher, self).__init__(conf, parsed_url)
+        super().__init__(conf, parsed_url)
         options = urlparse.parse_qs(parsed_url.query)
         topics = options.pop('topic', [default_topic])
         driver = options.pop('driver', ['rabbit'])[0]
@@ -258,11 +254,11 @@ class NotifierPublisher(MessagingPublisher):
 
 class SampleNotifierPublisher(NotifierPublisher):
     def __init__(self, conf, parsed_url):
-        super(SampleNotifierPublisher, self).__init__(
+        super().__init__(
             conf, parsed_url, conf.publisher_notifier.metering_topic)
 
 
 class EventNotifierPublisher(NotifierPublisher):
     def __init__(self, conf, parsed_url):
-        super(EventNotifierPublisher, self).__init__(
+        super().__init__(
             conf, parsed_url, conf.publisher_notifier.event_topic)
