@@ -22,7 +22,7 @@ class TestPublisher(publisher.ConfigPublisherBase):
     """Publisher used in unit testing."""
 
     def __init__(self, conf, parsed_url):
-        super(TestPublisher, self).__init__(conf, parsed_url)
+        super().__init__(conf, parsed_url)
         self.samples = []
         self.events = []
         self.calls = 0
