@@ -18,12 +18,12 @@ from oslo_config import cfg
 import oslo_i18n
 from oslo_log import log
 from oslo_reports import guru_meditation_report as gmr
+from oslo_reports import opts as gmr_opts
 
 from ceilometer import keystone_client
 from ceilometer import messaging
 from ceilometer import opts
 from ceilometer import sample
-from ceilometer import utils
 from ceilometer import version
 
 
@@ -52,9 +52,9 @@ def prepare_service(argv=None, config_files=None, conf=None):
     keystone_client.post_register_keystoneauth_opts(conf)
 
     log.setup(conf, 'ceilometer')
-    utils.setup_root_helper(conf)
     sample.setup(conf)
 
-    gmr.TextGuruMeditation.setup_autorun(version)
+    gmr_opts.set_defaults(conf)
+    gmr.TextGuruMeditation.setup_autorun(version, conf=conf)
     messaging.setup()
     return conf
