@@ -18,6 +18,7 @@ import datetime
 from unittest import mock
 import uuid
 
+from oslo_utils import timeutils
 from oslotest import base
 import requests
 from urllib import parse as urlparse
@@ -41,7 +42,7 @@ class TestHttpPublisher(base.BaseTestCase):
             user_id='test',
             project_id='test',
             resource_id=resource_id,
-            timestamp=datetime.datetime.utcnow().isoformat(),
+            timestamp=timeutils.utcnow().isoformat(),
             resource_metadata={'name': 'TestPublish'},
         ),
         sample.Sample(
@@ -52,7 +53,7 @@ class TestHttpPublisher(base.BaseTestCase):
             user_id='test',
             project_id='test',
             resource_id=resource_id,
-            timestamp=datetime.datetime.utcnow().isoformat(),
+            timestamp=timeutils.utcnow().isoformat(),
             resource_metadata={'name': 'TestPublish'},
         ),
         sample.Sample(
@@ -70,11 +71,11 @@ class TestHttpPublisher(base.BaseTestCase):
 
     event_data = [event.Event(
         message_id=str(uuid.uuid4()), event_type='event_%d' % i,
-        generated=datetime.datetime.utcnow().isoformat(),
+        generated=timeutils.utcnow().isoformat(),
         traits=[], raw={'payload': {'some': 'aa'}}) for i in range(3)]
 
     def setUp(self):
-        super(TestHttpPublisher, self).setUp()
+        super().setUp()
         self.CONF = service.prepare_service([], [])
 
     def test_http_publisher_config(self):
