@@ -14,11 +14,11 @@
 # under the License.
 """Tests for ceilometer/publisher/udp.py"""
 
-import datetime
 from unittest import mock
 
 import msgpack
 from oslo_utils import netutils
+from oslo_utils import timeutils
 from oslotest import base
 
 from ceilometer.publisher import udp
@@ -40,7 +40,7 @@ class TestUDPPublisher(base.BaseTestCase):
             user_id='test',
             project_id='test',
             resource_id='test_run_tasks',
-            timestamp=datetime.datetime.utcnow().isoformat(),
+            timestamp=timeutils.utcnow().isoformat(),
             resource_metadata={'name': 'TestPublish'},
             source=COUNTER_SOURCE,
         ),
@@ -52,7 +52,7 @@ class TestUDPPublisher(base.BaseTestCase):
             user_id='test',
             project_id='test',
             resource_id='test_run_tasks',
-            timestamp=datetime.datetime.utcnow().isoformat(),
+            timestamp=timeutils.utcnow().isoformat(),
             resource_metadata={'name': 'TestPublish'},
             source=COUNTER_SOURCE,
         ),
@@ -64,7 +64,7 @@ class TestUDPPublisher(base.BaseTestCase):
             user_id='test',
             project_id='test',
             resource_id='test_run_tasks',
-            timestamp=datetime.datetime.utcnow().isoformat(),
+            timestamp=timeutils.utcnow().isoformat(),
             resource_metadata={'name': 'TestPublish'},
             source=COUNTER_SOURCE,
         ),
@@ -76,7 +76,7 @@ class TestUDPPublisher(base.BaseTestCase):
             user_id='test',
             project_id='test',
             resource_id='test_run_tasks',
-            timestamp=datetime.datetime.utcnow().isoformat(),
+            timestamp=timeutils.utcnow().isoformat(),
             resource_metadata={'name': 'TestPublish'},
             source=COUNTER_SOURCE,
         ),
@@ -88,7 +88,7 @@ class TestUDPPublisher(base.BaseTestCase):
             user_id='test',
             project_id='test',
             resource_id='test_run_tasks',
-            timestamp=datetime.datetime.utcnow().isoformat(),
+            timestamp=timeutils.utcnow().isoformat(),
             resource_metadata={'name': 'TestPublish'},
             source=COUNTER_SOURCE,
         ),
@@ -107,7 +107,7 @@ class TestUDPPublisher(base.BaseTestCase):
         return _fake_socket_socket
 
     def setUp(self):
-        super(TestUDPPublisher, self).setUp()
+        super().setUp()
         self.CONF = service.prepare_service([], [])
         self.CONF.publisher.telemetry_secret = 'not-so-secret'
 
@@ -143,7 +143,7 @@ class TestUDPPublisher(base.BaseTestCase):
 
     @staticmethod
     def _raise_ioerror(*args):
-        raise IOError
+        raise OSError
 
     def _make_broken_socket(self, family, type):
         udp_socket = mock.Mock()
