@@ -71,14 +71,7 @@ function _ceilometer_install_redis {
     else
         # This will fail (correctly) where a redis package is unavailable
         install_package redis
-        if is_suse; then
-            # opensuse intsall multi-instance version of redis
-            # and admin is expected to install the required conf
-            cp /etc/redis/default.conf.example /etc/redis/default.conf
-            restart_service redis@default
-        else
-            restart_service redis
-        fi
+        restart_service redis
     fi
 
     pip_install_gr redis
@@ -95,6 +88,7 @@ function _ceilometer_prepare_coordination {
 
 # Create ceilometer related accounts in Keystone
 function ceilometer_create_accounts {
+    local gnocchi_service
     create_service_user "ceilometer" "admin"
 
     if is_service_enabled swift; then
@@ -104,8 +98,7 @@ function ceilometer_create_accounts {
 
     if [[ "$CEILOMETER_BACKENDS" =~ "gnocchi" ]]; then
         create_service_user "gnocchi"
-        local gnocchi_service=$(get_or_create_service "gnocchi" \
-            "metric" "OpenStack Metric Service")
+        gnocchi_service=$(get_or_create_service "gnocchi" "metric" "OpenStack Metric Service")
         get_or_create_endpoint $gnocchi_service \
             "$REGION_NAME" \
             "$(gnocchi_service_url)" \
@@ -166,7 +159,7 @@ function cleanup_ceilometer {
     sudo rmdir "$CEILOMETER_CONF_DIR"
 }
 
-# Set configuraiton for cache backend.
+# Set configuration for cache backend.
 # NOTE(cdent): This currently only works for redis. Still working
 # out how to express the other backends.
 function _ceilometer_configure_cache_backend {
@@ -193,8 +186,7 @@ function _ceilometer_configure_storage_backend {
         head -n -1 $CEILOMETER_CONF_DIR/event_pipeline.yaml > $CEILOMETER_CONF_DIR/tmp ; mv $CEILOMETER_CONF_DIR/tmp $CEILOMETER_CONF_DIR/event_pipeline.yaml
 
         BACKENDS=$(echo $CEILOMETER_BACKENDS | tr "," "\n")
-        for CEILOMETER_BACKEND in ${BACKENDS[@]}
-        do
+        for CEILOMETER_BACKEND in ${BACKENDS[@]}; do
             if [ "$CEILOMETER_BACKEND" = 'gnocchi' ] ; then
                 echo "          - gnocchi://?archive_policy=${GNOCCHI_ARCHIVE_POLICY}&filter_project=service" >> $CEILOMETER_CONF_DIR/event_pipeline.yaml
                 echo "          - gnocchi://?archive_policy=${GNOCCHI_ARCHIVE_POLICY}&filter_project=service" >> $CEILOMETER_CONF_DIR/pipeline.yaml
